@@ -77,7 +77,7 @@
 #define __NR_splice 76
 #define __NR_tee 77
 #define __NR_readlinkat 78
-#define __NR_fstatat 79
+#define __NR_newfstatat 79
 #define __NR_fstat 80
 #define __NR_sync 81
 #define __NR_fsync 82
@@ -242,7 +242,6 @@
 #define __NR_perf_event_open 241
 #define __NR_accept4 242
 #define __NR_recvmmsg 243
-#define __NR_or1k_atomic 244
 #define __NR_wait4 260
 #define __NR_prlimit64 261
 #define __NR_fanotify_init 262
@@ -354,7 +353,7 @@
 #define SYS_splice 76
 #define SYS_tee 77
 #define SYS_readlinkat 78
-#define SYS_fstatat 79
+#define SYS_newfstatat 79
 #define SYS_fstat 80
 #define SYS_sync 81
 #define SYS_fsync 82
@@ -519,7 +518,6 @@
 #define SYS_perf_event_open 241
 #define SYS_accept4 242
 #define SYS_recvmmsg 243
-#define SYS_or1k_atomic 244
 #define SYS_wait4 260
 #define SYS_prlimit64 261
 #define SYS_fanotify_init 262
